@@ -17,10 +17,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this library.  If not, see <http://www.gnu.org/licenses/>
 '''
 Utility functions used in ibus-table
 '''
@@ -231,8 +229,11 @@ def get_default_keybindings(gsettings, database):
         # Of course one should maybe consider fixing the conflict
         # between the keys by using different SELECT_KEYS in that
         # table.
-        if name in list(valid_input_chars):
-            name = 'F' + str(index)
+        if len(name) == 1 and name in list(valid_input_chars):
+            if name in '123456789':
+                name = 'F' + name
+            elif name == '0':
+                name = 'F10'
         default_keybindings[
             'commit_candidate_%s' % (index + 1)
         ] = [name]
@@ -555,6 +556,8 @@ class ItAboutDialog(Gtk.AboutDialog):
             ])
         self.set_translator_credits(
             # Translators: put your names here, one name per line.
+            # The list of names of the translators for the current locale
+            # will be displayed in the “About ibus-table” dialog.
             _('translator-credits'))
         # self.set_artists('')
         self.set_documenters([
